==> gsphonebook-0.4.tar.bz2: gsphonebook-0.4/html/index.common.php <==
<?php
require("init.php");

#$xajax->registerEvent("logoutcheck", "beforeProcessing")

function html_blf() {
	$html = "<ul class='blf'>";
	for($i = 0; $i < sizeof($_SESSION['blf']); $i++) {
		$blf = $_SESSION['blf'][$i];
		$html .= "<li>";
		$extid = htmlspecialchars(implode("_", $blf['ext']));
		$html .= sprintf("<img id='led-%s' src='images/state-unknown.png' class='led' title='%s'>", $extid, _("Unknown"));
		$html .= sprintf(" %s", htmlspecialchars($blf['name']));
		$html .= sprintf("<div id='channels-%s' class='channel'></div>",
					$extid);
		$html .= "</li>";
	}
	$html .= "</ul>";

	$_SESSION['blf_states'] = array();
	$_SESSION['last_update'] = '1970-01-01';

	return $html;
}

function update_blf() {
	$query = sprintf("SELECT key, value FROM config WHERE uid = '%s' AND key LIKE 'blf_%%' ORDER BY key",
				$_SESSION['uid']);
	$result = pg_query($query);
	$result = pg_fetch_all($result);
	$_SESSION['blf'] = array();
	$_SESSION['blfexts'] = array();
	if($result)
		foreach($result as $row) {
			if(substr($row['key'], 0, 8) == 'blf_ext_') {
				$pos = (int)substr($row['key'], 8);
				$exts = explode("&", pg_escape_string($row['value']));	# This is send to the DB
				$_SESSION['blf'][$pos] = array('ext' => $exts);
				$_SESSION['blfexts'] = array_merge($_SESSION['blfexts'], $exts);
			} else if(substr($row['key'], 0, 9) == 'blf_name_') {
				$pos = (int)substr($row['key'], 9);
				$_SESSION['blf'][$pos]['name'] = $row['value'];
			}
		}
	$_SESSION['blfexts'] = array_unique($_SESSION['blfexts']);
}


include("callinfo.common.php");

$xajax->registerFunction("select_move");
$xajax->registerFunction("dial");

$xajax->registerFunction("pb_search");
$xajax->registerFunction("pb_editEntry");
$xajax->registerFunction("pb_saveEntry");
$xajax->registerFunction("pb_deleteEntry");

$xajax->registerFunction("history");
$xajax->registerFunction("history_search");

$xajax->registerFunction("up_display");
$xajax->registerFunction("up_save");
$xajax->registerFunction("up_blf_display");
$xajax->registerFunction("up_blf_save");
$xajax->registerFunction("up_pw_display");
$xajax->registerFunction("up_pw_save");

if($_SESSION['admin']) {
	$xajax->registerFunction("admin");

	$xajax->registerFunction("ulist_search");
	$xajax->registerFunction("ulist_editEntry");
	$xajax->registerFunction("ulist_saveEntry");
	$xajax->registerFunction("ulist_deleteEntry");
	
	$xajax->registerFunction("glist_search");
	$xajax->registerFunction("glist_editEntry");
	$xajax->registerFunction("glist_saveEntry");
	$xajax->registerFunction("glist_deleteEntry");

	$xajax->registerFunction("gp_display");
	$xajax->registerFunction("gp_save");
}




?>

==> gsphonebook-0.7a.tar.bz2: gsphonebook-0.7a/html/index.common.php <==
<?php
require("init.php");

function html_blf() {
	$html = "<ul class='blf'>";
	for($i = 0; $i < sizeof($_SESSION['blf']); $i++) {
		$blf = $_SESSION['blf'][$i];
		$html .= "<li>";
		$extid = htmlspecialchars(implode("_", $blf['ext']));
		if($blf['phone'])
			$html .= sprintf("<a href='#' id='dial-%s' onclick='xajax_dial(\"%s\")' title='%s'>",
						$extid, $blf['phone'], _("Dial"));
		$html .= sprintf("<img id='led-%s' src='images/state-unknown.png' class='led' title='%s'>", $extid, _("Unknown"));
		$html .= sprintf(" %s", htmlspecialchars($blf['name']));
		if($blf['phone'])
			$html .= "</a>";
		$html .= sprintf("<div id='channels-%s' class='channel'></div>",
					$extid);
		$html .= "</li>";
	}
	$html .= "</ul>";

	$_SESSION['blf_states'] = array();
	$_SESSION['last_update'] = '1970-01-01';

	return $html;
}

function update_blf() {
	$query = sprintf("SELECT key, value FROM config WHERE uid = '%s' AND key LIKE 'blf_%%' ORDER BY key",
				$_SESSION['uid']);
	$result = pg_query($query);
	$result = pg_fetch_all($result);
	$_SESSION['blf'] = array();
	$_SESSION['blfexts'] = array();
	if($result)
		foreach($result as $row) {
			if(substr($row['key'], 0, 8) == 'blf_ext_') {
				$pos = (int)substr($row['key'], 8);
				$exts = explode("&", pg_escape_string($row['value']));	# This is send to the DB
				$_SESSION['blf'][$pos] = array('ext' => $exts);
				$_SESSION['blfexts'] = array_merge($_SESSION['blfexts'], $exts);
			} else if(substr($row['key'], 0, 9) == 'blf_name_') {
				$pos = (int)substr($row['key'], 9);
				$_SESSION['blf'][$pos]['name'] = $row['value'];
			} else if(substr($row['key'], 0, 10) == 'blf_phone_') {
				$pos = (int)substr($row['key'], 10);
				$_SESSION['blf'][$pos]['phone'] = $row['value'];
			}
		}
	$_SESSION['blfexts'] = array_unique($_SESSION['blfexts']);
}


include("callinfo.common.php");

$xajax->registerFunction("select_move");
$xajax->registerFunction("dial");
$xajax->registerFunction("redirect");

$xajax->registerFunction("pb_search");
$xajax->registerFunction("pb_editEntry");
$xajax->registerFunction("pb_saveEntry");
$xajax->registerFunction("pb_deleteEntry");

$xajax->registerFunction("history");
$xajax->registerFunction("history_search");

$xajax->registerFunction("up_display");
$xajax->registerFunction("up_save");
$xajax->registerFunction("up_blf_display");
$xajax->registerFunction("up_blf_save");
$xajax->registerFunction("up_callinfo_display");
$xajax->registerFunction("up_callinfo_save");
$xajax->registerFunction("up_pw_display");
$xajax->registerFunction("up_pw_save");

if($_SESSION['admin']) {
	$xajax->registerFunction("admin");

	$xajax->registerFunction("ulist_search");
	$xajax->registerFunction("ulist_editEntry");
	$xajax->registerFunction("ulist_saveEntry");
	$xajax->registerFunction("ulist_deleteEntry");
	
	$xajax->registerFunction("glist_search");
	$xajax->registerFunction("glist_editEntry");
	$xajax->registerFunction("glist_saveEntry");
	$xajax->registerFunction("glist_deleteEntry");

	$xajax->registerFunction("gp_display");
	$xajax->registerFunction("gp_save");
}




?>
